' This script launches TernAPI GUI in the environment suitable
' for the interaction with MATLAB. It automatically detects MATLAB
' binaries in the PATH environment variable and takes into account
' the platform of ternapi_gui.exe (WIN32 or WIN64) by the analysis
' of PE file signatures
'
' Creates tapimlrun.bat file and runs ternapi_gui.exe from it.
'
' (C) 2015 Alexey Voskov

' Define the platform of PE file
Function GetPEPlatform(exeFileName)
	' Read binary PE file from disk
	Dim Stream: Set Stream = CreateObject("ADODB.Stream")
	Stream.Type = 1 ' Binary
	Stream.Open
	Stream.LoadFromFile(exeFileName)
	exeDump = Stream.Read
	Stream.Close
	' Find PE headers and "magic" signature in the optional header
	b1 = AscB(MidB(exeDump, &H3C + 1, 1))
	b2 = AscB(MidB(exeDump, &H3D + 1, 1))
	pe_offset = b1 + b2 * 256
	b1 = AscB(MidB(exeDump, &H18 + pe_offset + 1, 1))
	b2 = AscB(MidB(exeDump, &H19 + pe_offset + 1, 1))
	pe_magic = b1 + b2 * 256
	If pe_magic = &H10B Then
		GetPEPlatform = "win32"
	Else
		GetPEPlatform = "win64"
	End If
End Function


Function GetMATLABLibFolder(matlabDir)
	platform = GetPEPlatform("ternapi_gui.exe")
	Set objFSO = CreateObject("Scripting.FileSystemObject")
	Set objFolder = objFSO.GetFolder(matlabDir)
	Set colSubFolders = objFolder.SubFolders
	For Each strSubFolder in colSubFolders
		If InStr(strSubFolder, platform) <> 0 Then
			GetMATLABLibFolder = strSubFolder
			Exit For
		End If
	Next
End Function

' Get PATH variable
Set wshShell = CreateObject("WScript.Shell")
path = wshShell.ExpandEnvironmentStrings("%PATH%")
paths = Split(path, ";")

' Find MATLAB folder
libFolder = "<<>>"
For i = 0 to ubound(paths)
	If InStr(paths(i), "MATLAB") <> 0 and (InStr(paths(i), "a\bin") <> 0 Or InStr(paths(i), "b\bin") <> 0) Then
		libFolder = GetMATLABLibFolder(paths(i))
		Exit For
	End If
Next
If libFolder = "<<>>" Then
	Wscript.echo "Cannot find MATLAB libraries"
	WScript.Quit(1)
	return
End If

' Create BAT-file for launching GUI
Set objFSO = CreateObject("Scripting.FileSystemObject")
Set fp = objFSO.OpenTextFile("tapimlrun.bat", 2, True)
' Write to the file
fp.WriteLine "@ECHO OFF"
fp.WriteLine "REM Autogenerated script. Don't edit!"
fp.WriteLine "SET PATH=" + libFolder + ";%PATH%"
fp.WriteLine "start ternapi_gui.exe"
fp.Close
' Run the generated batch file
wshShell.Run("tapimlrun.bat")
WScript.Quit(0)
